@@ -16,6 +16,8 @@
 # Import APIs into API package:
 from linksaas_local_api.api.global_api import GlobalApi
 from linksaas_local_api.api.project_bug_api import ProjectBugApi
+from linksaas_local_api.api.project_channel_api import ProjectChannelApi
+from linksaas_local_api.api.project_content_block_api import ProjectContentBlockApi
 from linksaas_local_api.api.project_create_api import ProjectCreateApi
 from linksaas_local_api.api.project_doc_api import ProjectDocApi
 from linksaas_local_api.api.project_event_api import ProjectEventApi
